from django import template
from distutils.sysconfig import get_python_lib
from django.template import Library, loader, Context


register = template.Library()

@register.filter
def subtract(value, arg):
    try:
        arg = int(arg)
    except:
        arg = 1
    try:
        output = value - arg
    except:
        output = ''
    return output

@register.filter(name='paginator')
def paginator(object_list, request, **kwargs):
    path = 'paginator.html'
    kw = dict()
    for k,v in kwargs.items():
        kw[k] = v
    path = request.build_absolute_uri()
    # path.replace('')
    path_list = path.split('?page')
    path = path_list[0]
    path_list = path.split('&page')
    path = path_list[0]
    if '?' in path :
        path = path + '&'
    if '?' not in path:
        path = path + '?'
    # path.replace('&page=', '')
    # path.replace('?page=', '')
    data = {
        'obj_list': object_list,
        'path': path
    }
    data.update(kw)
    html = loader.render_to_string(
        path,
        data
    )

    return html


@register.simple_tag(takes_context=True)
def paginate(context, object_list,request, **kwargs):
    template_name = 'paginator.html'
    kw = dict()
    for k,v in kwargs.items():
        kw[k] = v
    path = request.build_absolute_uri()
    # path.replace('')
    path_list = path.split('?page')
    path = path_list[0]
    path_list = path.split('&page')
    path = path_list[0]
    if '?' in path :
        path = path + '&'
    if '?' not in path:
        path = path + '?'
    # path.replace('&page=', '')
    # path.replace('?page=', '')
    data = {
        'obj_list': object_list,
        'path': path
    }
    data.update(kw)
    t = loader.get_template(template_name)
    return t.render(data)





import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="django-leafage",
    version="1.2.5",
    description="Simple and Easiest paginator for Django.",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/nilesh-kr-dubey/django-leafage",
    author="Nilesh Kumar Dubey",
    author_email="nileshdubeyindia@gmail.com",
    license="MIT",
    classifiers=[
        "Environment :: Web Environment",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
    ],
    packages=['leafage'],
    install_requires=[
        "Django >= 2.0",
    ],
    include_package_data=True,
)
